@@ -27,6 +27,7 @@ from .models import (
     BluetoothServiceInfoBleak,
     HaBluetoothConnector,
     HaScannerDetails,
+    HaScannerType,
 )
 from .scanner_device import BluetoothScannerDevice
 from .storage import DiscoveredDeviceAdvertisementData
@@ -92,11 +93,26 @@ class BaseHaScanner:
         self._cancel_watchdog: asyncio.TimerHandle | None = None
         self._loop: asyncio.AbstractEventLoop | None = None
         self._manager = get_manager()
+        # Determine scanner type based on class type
+        scanner_type = HaScannerType.UNKNOWN
+        if isinstance(self, BaseHaRemoteScanner):
+            scanner_type = HaScannerType.REMOTE
+        # Try to get adapter type from manager's cached adapters
+        elif (
+            (adapters := self._manager.get_cached_bluetooth_adapters())
+            and (adapter_details := adapters.get(adapter))
+            and (adapter_type := adapter_details.get("adapter_type"))
+        ):
+            if adapter_type == "usb":
+                scanner_type = HaScannerType.USB
+            elif adapter_type == "uart":
+                scanner_type = HaScannerType.UART
         self.details = HaScannerDetails(
             source=self.source,
             connectable=self.connectable,
             name=self.name,
             adapter=self.adapter,
+            scanner_type=scanner_type,
         )
         self._previous_service_info: dict[str, BluetoothServiceInfoBleak] = {}
         # Scanners only care about connectable devices. The manager
@@ -134,6 +150,9 @@ class BaseHaScanner:
     def _add_connecting(self, address: str) -> None:
         """Add a connecting."""
         self._increase_count(self._connect_in_progress, address)
+        # Clear timing collection data when scanner pauses for connection
+        # to prevent collecting invalid advertising interval data
+        self._manager._advertisement_tracker.async_scanner_paused(self.source)
 
     def _remove_connecting(self, address: str) -> None:
         """Remove a connecting."""
